@@ -47,7 +47,7 @@ class RedshiftCreateClusterTrigger(AwsBaseWaiterTrigger):
         cluster_identifier: str,
         poll_interval: int | None = None,
         max_attempt: int | None = None,
-        aws_conn_id: str = "aws_default",
+        aws_conn_id: str | None = "aws_default",
         waiter_delay: int = 15,
         waiter_max_attempts: int = 999999,
     ):
@@ -95,7 +95,7 @@ class RedshiftPauseClusterTrigger(AwsBaseWaiterTrigger):
         cluster_identifier: str,
         poll_interval: int | None = None,
         max_attempts: int | None = None,
-        aws_conn_id: str = "aws_default",
+        aws_conn_id: str | None = "aws_default",
         waiter_delay: int = 15,
         waiter_max_attempts: int = 999999,
     ):
@@ -143,7 +143,7 @@ class RedshiftCreateClusterSnapshotTrigger(AwsBaseWaiterTrigger):
         cluster_identifier: str,
         poll_interval: int | None = None,
         max_attempts: int | None = None,
-        aws_conn_id: str = "aws_default",
+        aws_conn_id: str | None = "aws_default",
         waiter_delay: int = 15,
         waiter_max_attempts: int = 999999,
     ):
@@ -191,7 +191,7 @@ class RedshiftResumeClusterTrigger(AwsBaseWaiterTrigger):
         cluster_identifier: str,
         poll_interval: int | None = None,
         max_attempts: int | None = None,
-        aws_conn_id: str = "aws_default",
+        aws_conn_id: str | None = "aws_default",
         waiter_delay: int = 15,
         waiter_max_attempts: int = 999999,
     ):
@@ -236,7 +236,7 @@ class RedshiftDeleteClusterTrigger(AwsBaseWaiterTrigger):
         cluster_identifier: str,
         poll_interval: int | None = None,
         max_attempts: int | None = None,
-        aws_conn_id: str = "aws_default",
+        aws_conn_id: str | None = "aws_default",
         waiter_delay: int = 30,
         waiter_max_attempts: int = 30,
     ):
@@ -278,7 +278,7 @@ class RedshiftClusterTrigger(BaseTrigger):
 
     def __init__(
         self,
-        aws_conn_id: str,
+        aws_conn_id: str | None,
         cluster_identifier: str,
         target_status: str,
         poke_interval: float,
